# Video Dataset

This is a python library to create a video dataset. The project is inspired from [Video-Dataset-Loading-Pytorch
](https://github.com/RaivoKoot/Video-Dataset-Loading-Pytorch) but with a lot of additional features and modifications.

The goal is to have a very moldable and customizable video dataset that can be reused in all possible video dataset situations.
